==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/SuperGlueSpawnPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllPackets;
import net.minecraft.class_1297;
import net.minecraft.class_238;
import net.minecraft.class_2596;
import net.minecraft.class_2604;
import net.minecraft.class_3231;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public class SuperGlueSpawnPacket extends class_2604 {
    public static final class_9139<class_9129, SuperGlueSpawnPacket> field_47896 = class_2596.method_56443(
        SuperGlueSpawnPacket::method_55855,
        SuperGlueSpawnPacket::new
    );
    private final class_238 box;

    public SuperGlueSpawnPacket(class_1297 entity, class_3231 entityTrackerEntry) {
        super(entity, entityTrackerEntry);
        box = entity.method_5829();
    }

    private SuperGlueSpawnPacket(class_9129 buf) {
        super(buf);
        box = new class_238(buf.readDouble(), buf.readDouble(), buf.readDouble(), buf.readDouble(), buf.readDouble(), buf.readDouble()).method_989(
            method_11175(),
            method_11174(),
            method_11176()
        );
    }

    @Override
    public void method_55855(class_9129 buf) {
        super.method_55855(buf);
        class_238 box = this.box.method_989(-method_11175(), -method_11174(), -method_11176());
        buf.method_52940(box.field_1323);
        buf.method_52940(box.field_1322);
        buf.method_52940(box.field_1321);
        buf.method_52940(box.field_1320);
        buf.method_52940(box.field_1325);
        buf.method_52940(box.field_1324);
    }

    public class_238 getBox() {
        return box;
    }

    @Override
    @SuppressWarnings("unchecked")
    public class_9145<class_2604> method_65080() {
        return (class_9145<class_2604>) (class_9145<?>) AllPackets.SUPER_GLUE_SPAWN;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/SuperGlueSpawnPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllPackets;
import net.minecraft.class_1297;
import net.minecraft.class_238;
import net.minecraft.class_2596;
import net.minecraft.class_2604;
import net.minecraft.class_3231;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public class SuperGlueSpawnPacket extends class_2604 {
    public static final class_9139<class_9129, SuperGlueSpawnPacket> CODEC = class_2596.method_56443(
        SuperGlueSpawnPacket::method_55855,
        SuperGlueSpawnPacket::new
    );
    private final class_238 box;

    public SuperGlueSpawnPacket(class_1297 entity, class_3231 entityTrackerEntry) {
        super(entity, entityTrackerEntry);
        box = entity.method_5829();
    }

    private SuperGlueSpawnPacket(class_9129 buf) {
        super(buf);
        box = new class_238(buf.readDouble(), buf.readDouble(), buf.readDouble(), buf.readDouble(), buf.readDouble(), buf.readDouble()).method_989(
            method_11175(),
            method_11174(),
            method_11176()
        );
    }

    @Override
    public void method_55855(class_9129 buf) {
        super.method_55855(buf);
        class_238 box = this.box.method_989(-method_11175(), -method_11174(), -method_11176());
        buf.method_52940(box.field_1323);
        buf.method_52940(box.field_1322);
        buf.method_52940(box.field_1321);
        buf.method_52940(box.field_1320);
        buf.method_52940(box.field_1325);
        buf.method_52940(box.field_1324);
    }

    public class_238 getBox() {
        return box;
    }

    @Override
    @SuppressWarnings("unchecked")
    public class_9145<class_2604> method_65080() {
        return (class_9145<class_2604>) (class_9145<?>) AllPackets.SUPER_GLUE_SPAWN;
    }
}
